mailr4397 - /1.3/test_suite/unit_tests/_prompt/test_structure.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on January 06, 2008 - 12:49:
Author: bugman
Date: Sun Jan  6 12:49:35 2008
New Revision: 4397

URL: http://svn.gna.org/viewcvs/relax?rev=4397&view=rev
Log:
Bug fix for the scale arg unit test of the structure.create_diff_tensor_pdb() 
user function.

Bin args are now caught as well.


Modified:
    1.3/test_suite/unit_tests/_prompt/test_structure.py

Modified: 1.3/test_suite/unit_tests/_prompt/test_structure.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/test_suite/unit_tests/_prompt/test_structure.py?rev=4397&r1=4396&r2=4397&view=diff
==============================================================================
--- 1.3/test_suite/unit_tests/_prompt/test_structure.py (original)
+++ 1.3/test_suite/unit_tests/_prompt/test_structure.py Sun Jan  6 12:49:35 
2008
@@ -46,8 +46,8 @@
 
         # Loop over the data types.
         for data in DATA_TYPES:
-            # Catch the float and int arguments, and skip them.
-            if data[0] == 'float' or data[0] == 'int':
+            # Catch the float, bin, and int arguments, and skip them.
+            if data[0] == 'float' or data[0] == 'bin' or data[0] == 'int':
                 continue
 
             # The argument test.




Related Messages


Powered by MHonArc, Updated Sun Jan 06 21:00:26 2008